@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.11.2.1 2002/07/22 13:50:35 kmaraas Exp $ */
+/* $Id: gdict-about.c,v 1.15 2003/05/19 12:34:23 cneumair Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -54,10 +54,8 @@ static GtkWidget *gdict_about_new (void)
     g_free (file);    
     
     about = gnome_about_new (_("GNOME Dictionary"), VERSION,
-                            _("Copyright 1999 by Mike Hughes"),
-                            _("Client for MIT dictionary server.\n"
-			      "Web: http://gdict.dhs.org/, "
-			      "http://www.psilord.com/code/"),
+                            "Copyright \xc2\xa9 1999-2003 Mike Hughes",
+                            _("A client for the MIT dictionary server."),
 			     (const char **)authors,
 			     (const char **)documenters,
 			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
