@@ -32,6 +32,8 @@
 #define SILENT_WINDOW_OPEN_LIMIT 5
 
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnome/gnome-desktop-item.h>
 
 #include <string.h>
 #include <signal.h>
@@ -94,42 +96,62 @@ help_cb (GtkWidget 	*widget,
 	if (error) {
 		GtkWidget *dialog;
 
-                dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                        GTK_MESSAGE_ERROR,
-                        GTK_BUTTONS_OK,
-                        error->message);
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_BUTTONS_OK,
+		                                     _("Could not open help document"),
+						     error->message);
 
                 g_signal_connect (G_OBJECT (dialog),
-                        "response",
-                        G_CALLBACK (gtk_widget_destroy), NULL);
+                                  "response",
+                                  G_CALLBACK (gtk_widget_destroy), NULL);
 		
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Can't Display Help"));	
-                gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
                 gtk_widget_show (dialog);
                 g_error_free (error);
         }
 }
 
+void
+click_check_button_cb (GtkWidget	*widget, 
+	       	       gpointer 	data)
+{
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) == TRUE) {
+		gtk_widget_show (interface.additional_constraints);
+		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
+		                               GTK_WIDGET (interface.main_window),
+		                               &interface.geometry, 
+	                                       GDK_HINT_MIN_SIZE);
+	} 
+	else {
+		GdkGeometry 		default_geometry;
+		
+		default_geometry.min_height = MINIMUM_WINDOW_HEIGHT;
+		default_geometry.min_width  = MINIMUM_WINDOW_WIDTH;
+		
+		gtk_widget_hide (interface.additional_constraints);
+		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
+		                               GTK_WIDGET (interface.main_window),
+		                               &default_geometry, 
+		                               GDK_HINT_MIN_SIZE);
+	}
+}
+
 void
 click_find_cb (GtkWidget	*widget, 
 	       gpointer 	data)
 {
 	gchar *command;
 
+	if (search_command.not_running_timeout == TRUE) {
+		return;
+	}
+
 	gtk_widget_set_sensitive (interface.stop_button, FALSE);
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 
 	command = build_search_command ();
 	
-	if (search_command.lock == FALSE) {	
-		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
-		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), 
-				   _("Searching..."));
-		search_command.timeout = g_timeout_add (100, update_progress_bar, 
-						  	NULL); 
-		search_command.show_hidden_files = FALSE;
-		
+	if (search_command.lock == FALSE) {
 		spawn_search_command (command);
 	}
 	
@@ -185,7 +207,7 @@ remove_constraint_cb (GtkWidget 	*widget,
 {
 	SearchConstraint *constraint = data;
 	
-      	interface.geometry.min_height -= 30;
+      	interface.geometry.min_height -= 35;
 	
 	gtk_window_set_geometry_hints (GTK_WINDOW(interface.main_window), 
 				       GTK_WIDGET(interface.main_window),
@@ -279,33 +301,28 @@ open_file_cb (GtkWidget 	*widget,
 	
 		GtkWidget *dialog;
 		gchar     *title;
+		gchar     *message;
 		gint      response;
 
-        	dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-                       		GTK_DIALOG_MODAL,
-                       		GTK_MESSAGE_QUESTION,
-                       		GTK_BUTTONS_NONE,
-                      		_("This will open %d separate files. Are you sure you want to do this?"),
-				g_list_length (list));
+		title = g_strdup_printf (_("Open %d documents?"), g_list_length (list));
+		message = g_strdup_printf (_("This will open %d separate documents. Are you sure you want to do this?"),
+		                           g_list_length (list));
 
-		title = g_strdup_printf (_("Open %d Files?"), g_list_length (list));
-		gtk_window_set_title (GTK_WINDOW (dialog), title);
-		
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-            		GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-            		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-            		NULL);
-		
-		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+			                             0 /* flags */,
+						     GTK_BUTTONS_OK_CANCEL,
+						     title,
+						     message);
 		
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
+		g_free (title);        
+		g_free (message);
 		
-		if (response == GTK_RESPONSE_REJECT) {
+		if (response == GTK_RESPONSE_CANCEL) {
 			g_list_free (list);
 			return;
 		}
-		g_free (title);        
 	}
 		
 	for (index = 0; index < g_list_length(list); index++) {
@@ -340,21 +357,25 @@ open_file_cb (GtkWidget 	*widget,
 				
 					if (launch_file (locale_file) == FALSE) {
 						GtkWidget *dialog;
+						gchar     *title;
+						gchar     *text;
 
-                				dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-                        				GTK_DIALOG_DESTROY_WITH_PARENT,
-                        				GTK_MESSAGE_ERROR,
-                        				GTK_BUTTONS_OK,
-                        				_("There is no installed viewer capable of displaying \"%s\"."),
-							file);
-
+						title = g_strdup_printf (_("Could not open document \"%s\""),
+									 g_path_get_basename (file));
+						text = g_strdup (_("There is no installed viewer capable of displaying the document."));	
+							
+						dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+						                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+										     GTK_BUTTONS_OK,
+										     title,
+										     text);
                 				g_signal_connect (G_OBJECT (dialog),
                         				"response",
                         				G_CALLBACK (gtk_widget_destroy), NULL);
-				
-       	         				gtk_window_set_title (GTK_WINDOW (dialog), _("Can't Display Location"));
-       	         				gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
 	                			gtk_widget_show (dialog);
+						g_free (title);
+						g_free (text);
 					}
 				}
 			} 
@@ -384,33 +405,27 @@ open_folder_cb (GtkWidget 	*widget,
 	if (g_list_length (list) > SILENT_WINDOW_OPEN_LIMIT) {
 		GtkWidget *dialog;
 		gchar     *title;
+		gchar     *message;
 		gint      response;
 
-        	dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-                       		GTK_DIALOG_MODAL,
-                       		GTK_MESSAGE_QUESTION,
-                       		GTK_BUTTONS_NONE,
-                      		_("This will open %d separate folders. Are you sure you want to do this?"),
-				g_list_length (list));
+		title = g_strdup_printf (_("Open %d folders?"), g_list_length (list));
+		message = g_strdup_printf (_("This will open %d separate folders. Are you sure you want to do this?"),
+		                           g_list_length (list));
 
-		title = g_strdup_printf (_("Open %d Folders?"), g_list_length (list));
-		gtk_window_set_title (GTK_WINDOW (dialog), title);
-		
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-            		GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-            		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-            		NULL);
-		
-		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
-		
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+			                             0 /* flags */,
+						     GTK_BUTTONS_OK_CANCEL,
+						     title,
+								  message);		
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
-		
-		if (response == GTK_RESPONSE_REJECT) {
+		g_free (title); 
+		g_free (message);
+				
+		if (response == GTK_RESPONSE_CANCEL) {
 			g_list_free (list);
 			return;
 		}
-		g_free (title);      
 	}
 		
 	for (index = 0; index < g_list_length(list); index++) {
@@ -432,8 +447,22 @@ open_folder_cb (GtkWidget 	*widget,
 			open_file_with_nautilus (folder_locale);
 		}
 		else {
-			gnome_error_dialog_parented (_("The nautilus file manager is not running."),
-						       GTK_WINDOW(interface.main_window));
+			GtkWidget *dialog;
+			gchar *title;
+			
+			title = g_strdup_printf (_("Could not open folder \"%s\""), folder_utf8);
+						       
+			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+		                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+				  		             GTK_BUTTONS_OK,
+							     title,
+							     _("The nautilus file manager is not running."));
+			
+			g_signal_connect (G_OBJECT (dialog),
+                        		  "response",
+                        		  G_CALLBACK (gtk_widget_destroy), NULL);
+
+	                gtk_widget_show (dialog);			
 			g_free (folder_locale);
 			g_free (folder_utf8);
 			g_list_free (list);
@@ -613,21 +642,25 @@ file_event_after_cb  (GtkWidget 	*widget,
 				
 					if (launch_file (locale_file) == FALSE) {
 						GtkWidget *dialog;
+						gchar     *title;
+						gchar     *text;
 
-                				dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-                        				GTK_DIALOG_DESTROY_WITH_PARENT,
-                        				GTK_MESSAGE_ERROR,
-                        				GTK_BUTTONS_OK,
-                        				_("There is no installed viewer capable of displaying \"%s\"."),
-							file);
+						title = g_strdup_printf (_("Could not open document \"%s\""), g_path_get_basename (file));
+						text = g_strdup (_("There is no installed viewer capable of displaying the document."));	
+							
+						dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+						                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+										     GTK_BUTTONS_OK,
+										     title,
+										     text);
 
                 				g_signal_connect (G_OBJECT (dialog),
                         				"response",
                         				G_CALLBACK (gtk_widget_destroy), NULL);
-				
-       	         				gtk_window_set_title (GTK_WINDOW (dialog), _("Can't Display Location"));
-       	         				gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
 	                			gtk_widget_show (dialog);
+						g_free (title);
+						g_free (text);
 					}
 				}
 			} 
@@ -723,6 +756,74 @@ drag_file_cb  (GtkWidget          *widget,
 	g_free (uri_list);
 }
 
+void  
+drag_data_animation_cb (GtkWidget          *widget,
+                        GdkDragContext     *context,
+                        GtkSelectionData   *selection_data,
+                        guint               info,
+                        guint               time,
+                        gpointer            data)
+{
+	GnomeDesktopItem *ditem;
+	GString          *command = g_string_new ("");
+	gchar            *uri;
+	gchar            *path;
+	gchar            *disk;
+	gchar            *scheme;
+	gchar		 *desktop_item_name = NULL;
+	gchar            **argv;
+	gint             argc, i;
+	
+	set_clone_command (&argc, &argv, "gnome-search-tool", TRUE);
+	
+	if (argc == 0) {
+		return;
+	}
+	
+	for (i = 0; i < argc; i++) {
+		command = g_string_append (command, argv[i]);
+		command = g_string_append_c (command, ' ');
+	}
+	command = g_string_append (command, "--start");
+		
+	disk = g_locale_from_utf8 (command->str, -1, NULL, NULL, NULL);
+	uri = gnome_vfs_make_uri_from_input_with_dirs (disk, GNOME_VFS_MAKE_URI_DIR_HOMEDIR);
+	scheme = gnome_vfs_get_uri_scheme (uri);
+	
+	ditem = gnome_desktop_item_new ();
+	
+	gnome_desktop_item_set_entry_type (ditem, GNOME_DESKTOP_ITEM_TYPE_APPLICATION);
+	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_EXEC, command->str);
+	
+	desktop_item_name = get_desktop_item_name ();
+	
+	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_NAME, desktop_item_name);
+	gnome_desktop_item_set_boolean (ditem, GNOME_DESKTOP_ITEM_TERMINAL, FALSE);					
+	gnome_desktop_item_set_string (ditem, GNOME_DESKTOP_ITEM_ICON, GNOME_SEARCH_TOOL_ICON);
+	gnome_desktop_item_set_boolean (ditem, "StartupNotify", TRUE);
+	
+	g_string_free (command, TRUE);
+	g_free (desktop_item_name);
+	g_free (uri);
+
+	path = gsearchtool_unique_filename (g_get_tmp_dir(), ".desktop");
+	gnome_desktop_item_set_location (ditem, path);
+
+	uri = gnome_vfs_get_uri_from_local_path (path);
+		
+	if (gnome_desktop_item_save (ditem, NULL, FALSE, NULL)) {
+		gtk_selection_data_set (selection_data,
+					selection_data->target, 8,
+					uri, strlen (uri));
+	}
+	gnome_desktop_item_unref (ditem);
+
+	g_free (uri);
+	g_free (path);
+	g_free (disk);
+	g_free (scheme);
+}
+
 void
 show_file_selector_cb (GtkWidget 	*widget, 
 		       gpointer		data)
@@ -770,42 +871,50 @@ save_results_cb (GtkFileSelection *selector,
 		
 		if (g_file_test (interface.save_results_file, G_FILE_TEST_IS_DIR) == TRUE) {
 			GtkWidget *dialog;
-			gchar *error_msg = g_strdup_printf (_("Cannot save search results.\n\"%s\" is a folder."),
-							      interface.save_results_file);
+			gchar *title_msg;
+			gchar *error_msg;
+			
+			title_msg = g_strdup_printf (_("Could not save document \"\" to %s"), 
+		                                     interface.save_results_file);
+					     
+			error_msg = g_strdup_printf (_("You did not select a document name or the name selected was a folder.  The document is not saved."));
 
-			dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-					GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_ERROR,
-					GTK_BUTTONS_OK,
-					error_msg);
+			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+			                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+							     GTK_BUTTONS_OK,
+							     title_msg,
+							     error_msg);
 
 			g_signal_connect (G_OBJECT (dialog),
 					"response",
 					G_CALLBACK (gtk_widget_destroy), NULL);
 					
-			gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 			gtk_widget_show (dialog);
+			g_free (title_msg);
 			g_free (error_msg);
 			
 			return;	
 		}
 		else {
 			GtkWidget *dialog;
-			gint response;
-		
-			dialog = gtk_message_dialog_new
-				(GTK_WINDOW (interface.file_selector),
-				 0 /* flags */,
-				 GTK_MESSAGE_QUESTION,
-				 GTK_BUTTONS_YES_NO,
-				 _("File \"%s\" already exists. Overwrite?"),
-				 interface.save_results_file);
-			gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW (interface.main_window));
+			gchar     *text;
+			gint      response;
+				 
+			text = g_strdup_printf (_("The contents of the file \"%s\" will be lost."), 
+			                        interface.save_results_file);
+			
+			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+			                                     0 /* flags */,
+							     GTK_BUTTONS_OK_CANCEL,
+							     _("Overwrite an existing file?"),
+							     text);
+			
 			response = gtk_dialog_run (GTK_DIALOG (dialog));
 		
 			gtk_widget_destroy (GTK_WIDGET(dialog));
-		
-			if (response != GTK_RESPONSE_YES) return;
+			g_free (text);
+			
+			if (response != GTK_RESPONSE_OK) return;
 		}
 	}
 	
@@ -817,39 +926,48 @@ save_results_cb (GtkFileSelection *selector,
 			
 			for (i = 0; i < n_children; i++)
 			{
-				gchar *utf8_path, *utf8_name, *file;
+				gchar *utf8_path, *utf8_name, *utf8_file, *locale_file;
 				
 				gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, COLUMN_PATH, &utf8_path, -1);
 				gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, COLUMN_NAME, &utf8_name, -1);
 				gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);	
-				
-				file = g_build_filename (utf8_path, utf8_name, NULL);					    
-				fprintf(fp, "%s\n", file);
+   
+				utf8_file = g_build_filename (utf8_path, utf8_name, NULL);					    
+				locale_file = g_filename_from_utf8 (utf8_file, -1, NULL, NULL, NULL);	
+				fprintf(fp, "%s\n", locale_file);
 				
 				g_free(utf8_path);
 				g_free(utf8_name);
-				g_free(file);
+				g_free(utf8_file);
+				g_free(locale_file);
 			}
 		}		 
 		fclose(fp);
 	} 
 	else {
 		GtkWidget *dialog;
-		gchar *error_msg = g_strdup_printf (_("Cannot save search results to the file \"%s\"."),
-						      interface.save_results_file);
-				
-		dialog = gtk_message_dialog_new (GTK_WINDOW (interface.main_window),
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				error_msg);
+		gchar *title_msg;
+		gchar *error_msg;
+		
+		title_msg = g_strdup_printf (_("Could not save document \"%s\" to %s"), 
+		                             g_path_get_basename (interface.save_results_file),
+					     g_path_get_dirname (interface.save_results_file));
+					     
+		error_msg = g_strdup_printf ("%s",
+		_("You may not have write permissions to the document.  The document is not saved."));
+						    						
+		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
+		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+						     GTK_BUTTONS_OK,
+						     title_msg,
+						     error_msg);
 
 		g_signal_connect (G_OBJECT (dialog),
 				"response",
 				G_CALLBACK (gtk_widget_destroy), NULL);
 					
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 		gtk_widget_show (dialog);
+		g_free (title_msg);
 		g_free (error_msg);
 	}
 }
@@ -866,7 +984,7 @@ save_session_cb (GnomeClient 	    *client,
 	char **argv;
 	int argc;
 
-	set_clone_command (&argc, &argv, client_data);
+	set_clone_command (&argc, &argv, client_data, FALSE);
 	gnome_client_set_clone_command (client, argc, argv);
 	gnome_client_set_restart_command (client, argc, argv);	
 }
