@@ -46,298 +46,6 @@
 #define ICON_THEME_EXECUTABLE_ICON "gnome-fs-executable"
 #define ICON_THEME_REGULAR_ICON    "gnome-fs-regular"
 
-/* START OF THE CDDB FUNCTIONS */
-
-static GtkCheckButtonClass *parent_class = NULL;
-
-struct _CDDBDisclosurePrivate {
-	GtkWidget *container;
-	char *shown;
-	char *hidden;
-	
-	guint32 expand_id;
-	GtkExpanderStyle style;
-
-	int expander_size;
-	int direction;
-};
-
-static void
-finalize (GObject *object)
-{
-	CDDBDisclosure *disclosure;
-
-	disclosure = CDDB_DISCLOSURE (object);
-	if (disclosure->priv == NULL) {
-		return;
-	}
-
-	g_free (disclosure->priv->hidden);
-	g_free (disclosure->priv->shown);
-
-	if (disclosure->priv->container != NULL) {
-		g_object_unref (G_OBJECT (disclosure->priv->container));
-	}
-	
-	g_free (disclosure->priv);
-	disclosure->priv = NULL;
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-static void
-cddb_disclosure_destroy(GtkObject *obj)
-{
-	CDDBDisclosure *disclosure = CDDB_DISCLOSURE (obj);
-
-	if (disclosure->priv->expand_id)
-		g_source_remove (disclosure->priv->expand_id);
-}
-
-static void
-get_x_y (CDDBDisclosure *disclosure,
-	 int *x,
-	 int *y,
-	 GtkStateType *state_type)
-{
-	GtkCheckButton *check_button;
-	int indicator_size, indicator_spacing;
-	int focus_width;
-	int focus_pad;
-	gboolean interior_focus;
-	GtkWidget *widget = GTK_WIDGET (disclosure);
-	GtkBin *bin = GTK_BIN (disclosure);
-	int width;
-	
-	if (GTK_WIDGET_VISIBLE (disclosure) &&
-	    GTK_WIDGET_MAPPED (disclosure)) {
-		check_button = GTK_CHECK_BUTTON (disclosure);
-		
-		gtk_widget_style_get (GTK_WIDGET (check_button),
-				      "indicator_size", &indicator_size,
-				      "indicator_spacing", &indicator_spacing,
-				      NULL);
-
-		gtk_widget_style_get (widget,
-				      "interior_focus", &interior_focus,
-				      "focus-line-width", &focus_width,
-				      "focus-padding", &focus_pad,
-				      NULL);
-		
-		*state_type = GTK_WIDGET_STATE (widget);
-		if ((*state_type != GTK_STATE_NORMAL) &&
-		    (*state_type != GTK_STATE_PRELIGHT)) {
-			*state_type = GTK_STATE_NORMAL;
-		}
-
-		if (bin->child) {
-			width = indicator_spacing * 3 + indicator_size ;
-		} else {
-			width = widget->allocation.width - 2 * GTK_CONTAINER (widget)->border_width;
-		}
-		
-		*x = widget->allocation.x + GTK_CONTAINER (widget)->border_width + (width) / 2;
-		*y = widget->allocation.y + widget->allocation.height / 2;
-
-		if (interior_focus == FALSE) {
-			*x += focus_width + focus_pad;
-		}
-
-		*state_type = GTK_WIDGET_STATE (widget) == GTK_STATE_ACTIVE ? GTK_STATE_NORMAL : GTK_WIDGET_STATE (widget);
-
-		if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) {
-			*x = widget->allocation.x + widget->allocation.width - (*x - widget->allocation.x);
-		}
-	} else {
-		*x = 0;
-		*y = 0;
-		*state_type = GTK_STATE_NORMAL;
-	}
-}
-
-static gboolean
-expand_collapse_timeout (gpointer data)
-{
-	GtkWidget *widget = data;
-	CDDBDisclosure *disclosure = data;
-	GtkStateType state_type;
-	int x, y;
-	
-	gdk_window_invalidate_rect (widget->window, &widget->allocation, TRUE);
-	get_x_y (disclosure, &x, &y, &state_type);
-	
-	gtk_paint_expander (widget->style,
-			    widget->window,
-			    state_type,
-			    &widget->allocation,
-			    widget,
-			    "disclosure",
-			    x, y,
-			    disclosure->priv->style);
-
-	disclosure->priv->style += disclosure->priv->direction;
-	if ((int) disclosure->priv->style > (int) GTK_EXPANDER_EXPANDED) {
-		disclosure->priv->style = GTK_EXPANDER_EXPANDED;
-
-		if (disclosure->priv->container != NULL) {
-			gtk_widget_show (disclosure->priv->container);
-		}
-
-		g_object_set (G_OBJECT (disclosure),
-			      "label", disclosure->priv->hidden,
-			      NULL);
-			      
-		constraint_entry_changed_cb (NULL, NULL);	      
-			      
-		return FALSE;
-	} else if ((int) disclosure->priv->style < (int) GTK_EXPANDER_COLLAPSED) {
-		disclosure->priv->style = GTK_EXPANDER_COLLAPSED;
-
-		if (disclosure->priv->container != NULL) {
-			gtk_widget_hide (disclosure->priv->container);
-		}
-
-		g_object_set (G_OBJECT (disclosure),
-			      "label", disclosure->priv->shown,
-			      NULL);
-
-		constraint_entry_changed_cb (NULL, NULL);
-
-		return FALSE;
-	} else {
-		return TRUE;
-	}
-}
-
-static void
-do_animation (CDDBDisclosure *disclosure,
-	      gboolean opening)
-{
-	if (disclosure->priv->expand_id > 0) {
-		g_source_remove (disclosure->priv->expand_id);
-	}
-
-	disclosure->priv->direction = opening ? 1 : -1;
-	disclosure->priv->expand_id = g_timeout_add (50, expand_collapse_timeout, disclosure);
-}
-
-static void
-toggled (GtkToggleButton *tb)
-{
-	CDDBDisclosure *disclosure;
-
-	disclosure = CDDB_DISCLOSURE (tb);
-	do_animation (disclosure, gtk_toggle_button_get_active (tb));
-
-	/*  Disabled for now.  By default we won't show the additional options section.
-	    But, keep the gconf key so advanced users can change the default behavior.
-	    
-	gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/show_additional_options",
-		       	       	       disclosure->priv->style == GTK_EXPANDER_COLLAPSED 
-				       ? TRUE : FALSE);
-	*/
-
-	if (disclosure->priv->container == NULL) {
-		return;
-	}
-}
-
-static void
-draw_indicator (GtkCheckButton *check,
-		GdkRectangle *area)
-{
-	GtkWidget *widget = GTK_WIDGET (check);
-	CDDBDisclosure *disclosure = CDDB_DISCLOSURE (check);
-	GtkStateType state_type;
-	int x, y;
-
-	get_x_y (disclosure, &x, &y, &state_type);
-	gtk_paint_expander (widget->style,
-			    widget->window,
-			    state_type,
-			    area,
-			    widget,
-			    "treeview",
-			    x, y,
-			    disclosure->priv->style);
-}
-
-static void
-class_init (CDDBDisclosureClass *klass)
-{
-	GtkObjectClass *gtk_object_class = (GtkObjectClass *) klass;
-	GObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-	GtkCheckButtonClass *button_class;
-	GtkToggleButtonClass *toggle_class;
-	
-	object_class = G_OBJECT_CLASS (klass);
-	widget_class = GTK_WIDGET_CLASS (klass);
-	button_class = GTK_CHECK_BUTTON_CLASS (klass);
-	toggle_class = GTK_TOGGLE_BUTTON_CLASS (klass);
-	
-	toggle_class->toggled = toggled;
-	button_class->draw_indicator = draw_indicator;
-
-	object_class->finalize = finalize;
-
-	gtk_object_class->destroy = cddb_disclosure_destroy;
-
-	parent_class = g_type_class_peek_parent (klass);
-
-	gtk_widget_class_install_style_property (widget_class,
-						 g_param_spec_int ("expander_size",
-								   _("Expander Size"),
-								   _("Size of the expander arrow"),
-								   0, G_MAXINT,
-								   10, G_PARAM_READABLE));
-}
-
-static void
-init (CDDBDisclosure *disclosure)
-{
-	disclosure->priv = g_new0 (CDDBDisclosurePrivate, 1);
-	disclosure->priv->expander_size = 10;
-}
-
-GType
-cddb_disclosure_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		GTypeInfo info = {
-			sizeof (CDDBDisclosureClass),
-			NULL, NULL, (GClassInitFunc) class_init, NULL, NULL,
-			sizeof (CDDBDisclosure), 0, (GInstanceInitFunc) init
-		};
-
-		type = g_type_register_static (GTK_TYPE_CHECK_BUTTON, "CDDBDisclosure", &info, 0);
-	}
-
-	return type;
-}
-
-GtkWidget *
-cddb_disclosure_new (const char *shown,
-		     const char *hidden)
-{
-	CDDBDisclosure *disclosure;
-
-	disclosure = g_object_new (cddb_disclosure_get_type (), "label", shown, NULL);
-
-	disclosure->priv->shown = g_strdup (shown);
-	disclosure->priv->hidden = g_strdup (hidden);
-	return GTK_WIDGET (disclosure);
-}
-
-void
-cddb_disclosure_set_container (CDDBDisclosure *disclosure,
-			       GtkWidget *container)
-{
-	g_object_ref (G_OBJECT (container));
-	disclosure->priv->container = container;
-}
 
 /* START OF THE GCONF FUNCTIONS */
 
@@ -579,16 +287,6 @@ count_of_char_in_string (const gchar *string,
 	return cnt;
 }
 
-gchar *
-get_date (const time_t file_time_raw)
-{
-	struct tm *file_time;
-	const char *format = _("%Y%m%d%H%M%S");
-
-	file_time = localtime (&file_time_raw);
-	return strdup_strftime (format, file_time);
-}
-
 gchar *
 get_readable_date (const time_t file_time_raw)
 {
@@ -879,3 +577,152 @@ launch_file (const gchar *filename)
 	g_free (mime_type);
 	return result;
 }
+
+gchar *
+gsearchtool_unique_filename (const gchar *dir,
+                             const gchar *suffix)
+{
+	const gint num_of_words = 12;
+	gchar      *words[] = {
+		    "foo",
+		    "bar",
+		    "blah",
+	   	    "gegl",
+		    "frobate",
+		    "hadjaha",
+		    "greasy",
+		    "hammer",
+		    "eek",
+		    "larry",
+		    "curly",
+		    "moe",
+		    NULL};
+	gchar      *retval = NULL;
+	gboolean   exists = TRUE;
+
+	while (exists) {
+		gchar *filename;
+		gint   rnd;
+		gint   word;
+
+		rnd = rand ();
+		word = rand () % num_of_words;
+
+		filename = g_strdup_printf ("%s-%010x%s",
+					    words [word],
+					    (guint) rnd,
+					    suffix);
+
+		g_free (retval);
+		retval = g_strconcat (dir, "/", filename, NULL);
+		exists = g_file_test (retval, G_FILE_TEST_EXISTS);
+		g_free (filename);
+	}
+	return retval;
+}
+
+GtkWidget*
+gsearchtool_hig_dialog_new (GtkWindow      *parent,
+                            GtkDialogFlags flags,
+                            GtkButtonsType buttons,
+                            const gchar    *header,
+                            const gchar    *message)
+{
+	GtkWidget *dialog;
+	GtkWidget *dialog_vbox;
+	GtkWidget *dialog_action_area;
+	GtkWidget *hbox;
+	GtkWidget *vbox;
+	GtkWidget *label;
+	GtkWidget *button;
+	GtkWidget *image;
+	gchar     *title;
+
+	dialog = gtk_dialog_new ();
+	
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+  
+	dialog_vbox = GTK_DIALOG (dialog)->vbox;
+	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 12);
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_widget_show (hbox);
+
+	if (buttons != GTK_BUTTONS_OK_CANCEL) {
+		image = gtk_image_new_from_stock ("gtk-dialog-error", GTK_ICON_SIZE_DIALOG);
+	}
+	else {
+		image = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
+	}
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	gtk_widget_show (image);
+
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
+	gtk_widget_show (vbox);
+	
+	title = g_strconcat ("<b>", header, "</b>", NULL);
+	label = gtk_label_new (title);  
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_widget_show (label);
+	g_free (title);
+	
+	label = gtk_label_new (message);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_widget_show (label);
+	
+	dialog_action_area = GTK_DIALOG (dialog)->action_area;
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+
+	switch (buttons) 
+  	{		
+		case GTK_BUTTONS_OK_CANCEL:
+	
+			button = gtk_button_new_from_stock ("gtk-cancel");
+  			gtk_widget_show (button);
+  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CANCEL);
+  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+
+		  	button = gtk_button_new_from_stock ("gtk-ok");
+  			gtk_widget_show (button);
+  			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+  			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+			break;
+		
+		case GTK_BUTTONS_OK:
+		
+			button = gtk_button_new_from_stock ("gtk-ok");
+			gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+			GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+			gtk_widget_show (button);
+			break;
+		
+		default:
+			g_warning ("Unhandled GtkButtonsType");
+			break;
+  	}
+
+	if (parent != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
+	}
+	if (flags & GTK_DIALOG_MODAL) {
+		gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	}
+	if (flags & GTK_DIALOG_DESTROY_WITH_PARENT) {
+		gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+	}
+	
+  	return dialog;
+}
